Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Gorc ¶
func (*Gorc) SetWaitMillis ¶
SetWaitMillis sets the time in milliseconds the Wait function waits between checking the count against the given integer.
Click to show internal directories.
Click to hide internal directories.